!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
!         Periodic waves in an a nonlinear parabolic PDE
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 

  SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
! ---------- ---- 

  IMPLICIT NONE
  INTEGER, INTENT(IN) :: NDIM, ICP(*), IJAC
  DOUBLE PRECISION, INTENT(IN) :: U(NDIM), PAR(*)
  DOUBLE PRECISION, INTENT(OUT) :: F(NDIM)
  DOUBLE PRECISION, INTENT(INOUT) :: DFDU(NDIM,NDIM), DFDP(NDIM,*)

  DOUBLE PRECISION s, a, lambda, s0, a0, rho, kappa1, kappa2, alpha, R

    lambda = PAR(1)
    s0     = PAR(2)
    a0     = PAR(3)
    rho    = PAR(4)
    kappa1 = PAR(5)
    kappa2 = PAR(6)
    alpha  = PAR(7)

    s = U(1)
    a = U(2)

    R   = s*a / ( (kappa1+a)*(1+s+kappa2*s*s) ) 

    F(1) =-lambda*( rho*R - (s0-s) ) 
    F(2) =-lambda*( rho*R - alpha*(a0-a) ) 

  END SUBROUTINE FUNC
!---------------------------------------------------------------------- 

  SUBROUTINE STPNT(NDIM,U,PAR,T)
! ---------- ----- 

  IMPLICIT NONE
  INTEGER, INTENT(IN) :: NDIM
  DOUBLE PRECISION, INTENT(INOUT) :: U(NDIM),PAR(*)
  DOUBLE PRECISION, INTENT(IN) :: T

  DOUBLE PRECISION s, a, lambda, s0, a0, rho, kappa1, kappa2, alpha
  DOUBLE PRECISION c, beta1, beta2

! Parameters in the equations:
    lambda = 3.0 
    s0     = 145 
    a0     = 620
    rho    = 210 
    kappa1 = 3.4 
    kappa2 = 0.023 
    alpha  = 0.2 

! The wave speed
   c = 0.05

! The diffusion constants:
   beta1 = 1.0
   beta2 =  5.0
!
   PAR(1)  = lambda
   PAR(2)  = s0
   PAR(3)  = a0
   PAR(4)  = rho
   PAR(5)  = kappa1
   PAR(6)  = kappa2
   PAR(7)  = alpha
   PAR(10) = c
   PAR(15) = beta1 
   PAR(16) = beta2 

! The starting equilibrium
   s = 5.38355d1
   a = 1.64177d2

   U(1) = s
   U(2) = a

  END SUBROUTINE STPNT
!---------------------------------------------------------------------- 

  SUBROUTINE BCND 
  END SUBROUTINE BCND

  SUBROUTINE ICND 
  END SUBROUTINE ICND

  SUBROUTINE FOPT 
  END SUBROUTINE FOPT

  SUBROUTINE PVLS
  END SUBROUTINE PVLS
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
